phoneengine/PhoneCntFinder/inc/CPhCntMatcher.h
branchRCL_3
changeset 57 94dc1107e8b2
parent 0 5f000ab63145
child 58 40a3f856b14d
--- a/phoneengine/PhoneCntFinder/inc/CPhCntMatcher.h	Mon Jun 21 15:39:45 2010 +0300
+++ b/phoneengine/PhoneCntFinder/inc/CPhCntMatcher.h	Thu Jul 15 18:38:16 2010 +0300
@@ -102,7 +102,7 @@
         /**
         * Match number to phonebook.
         * @param aMatch Found match, owership tranferred. NULL if not found any.
         * @param aNumber Number to match against.
         * @param aAllowUsernameMatch 
         *						is ETrue if username is sufficient for match.
         * @param aContactStoreUris
@@ -116,7 +116,7 @@
         */    
         virtual TInt MatchVoipNumber(
             MPhCntMatch*& aMatch,
-            const TDesC& aNumber,
+            const TDesC& aMatchString,
             const TBool aAllowUsernameMatch,
             MDesCArray* aContactStoreUris,
             TInt aCharsForMatching = 0 ) = 0;
@@ -126,6 +126,7 @@
         * by contact id.
         * @since Series60 3.0
         * @param aMatch for found match, owership tranferred. Empty if not found.
+        * @param aMatchString Number to match against.
         * @param aContactId for current contact.
         * @return Error code: KErrNone - VoIP call contact found
         *                     KErrNotFound - no VoIP call contact found
@@ -133,6 +134,7 @@
         */    
         virtual TInt MatchVoipNumber(
             MPhCntMatch*& aMatch,
+            const TDesC& aMatchString,
             const CPhCntContactId& aContactId ) = 0;
             
         /**
@@ -102,7 +102,7 @@
         * Match number to phonebook.
         * @param aMatch Found match, owership tranferred. NULL if not found any.
-        * @param aNumber Number to match against.
+        * @param aMatchString Number to match against.
         * @param aAllowUsernameMatch 
         *						is ETrue if username is sufficient for match.